require 'spec_helper'
require 'singularity'

describe Singularity do
  after(:each) { Singularity.configure.reset }

  context 'auth_path' do
    it "defaults to localhost:9292" do
      expect( subject.auth_path ).to eq 'http://localhost:9292'
    end

    it "is writeable" do
      subject.auth_path = 'http://authmaster.local:8080'

      expect( subject.auth_path ).to eq 'http://authmaster.local:8080'
    end
  end

  context 'session_prefix' do
    it "defaults to rack_session" do
      expect( subject.session_prefix ).to eq 'rack_session'
    end

    it "is writeable" do
      subject.session_prefix = 'foo'
      expect( subject.session_prefix ).to eq 'foo'
    end
  end

  context 'profile_prefix' do
    it "defaults to profile" do
      expect( subject.profile_prefix ).to eq 'profile'
    end

    it "is writeable" do
      subject.profile_prefix = 'user'
      expect( subject.profile_prefix ).to eq 'user'
    end
  end

  context 'token_prefix' do
    it "defaults to singularity_session_token" do
      expect( subject.token_prefix ).to eq 'singularity_session_token'
    end

    it "is writeable" do
      subject.token_prefix = 'token'
      expect( subject.token_prefix ).to eq 'token'
    end
  end

  context 'warden_user_key' do
    it "defaults to warden.user.default.key" do
      expect( subject.warden_user_key ).to eq 'warden.user.default.key'
    end

    it "is writeable" do
      subject.warden_user_key = 'singularity.user'
      expect( subject.warden_user_key ).to eq 'singularity.user'
    end
  end

  context 'configure' do
    it "returns config object if not given a block" do
      expect( subject.configure ).to be_a Singularity::Configuration
    end

    it "accepts a block to set configuration" do
      subject.configure do |config|
        config.auth_path       = 'http://foobar.local:8088'
        config.session_prefix  = 'foo_session'
        config.profile_prefix  = 'foo_user'
        config.token_prefix    = 'foo_token'
        config.warden_user_key = 'foo.user.key'
      end

      expect( subject.auth_path ).to       eq 'http://foobar.local:8088'
      expect( subject.session_prefix ).to  eq 'foo_session'
      expect( subject.profile_prefix ).to  eq 'foo_user'
      expect( subject.token_prefix ).to    eq 'foo_token'
      expect( subject.warden_user_key ).to eq 'foo.user.key'
    end
  end
end
