require 'spec_helper'
require 'singularity'
require 'singularity/profile'

describe Singularity::Profile do
  let(:redis) { MockRedis.new }

  subject { Singularity::Profile.new('me@example.com', redis: redis) }

  it "provides #password_hash" do
    expect{ subject.password_hash = 'foobar' }.to_not raise_error
    expect( subject.password_hash ).to eq 'foobar'
  end

  it "provides #password_salt" do
    expect{ subject.password_salt = 'baz' }.to_not raise_error
    expect( subject.password_salt ).to eq 'baz'
  end

  it "provides #password_iterations" do
    expect{ subject.password_iterations = 15_000 }.to_not raise_error
    expect( subject.password_iterations ).to eq 15_000
  end

  it "password_iterations returns default iterations if zero" do
    subject.password_iterations = 0
    expect( subject.password_iterations ).to eq Singularity::PasswordHash.iterations
  end

  it "passes through [] methods to profile hash" do
    subject['foo'] = 'bar'
    expect( redis.hget('profile:me@example.com', 'foo') ).to eq 'bar'
  end

  it "provides #password?" do
    subject.password_salt       = SecureRandom.hex(32)
    subject.password_iterations = 25_000
    subject.password_hash       = Singularity::PasswordHash.generate('passw0rd', subject.password_salt, iterations: 25_000)

    expect( subject.password?('passw0rd') ).to be true
  end
end
